==> haskell-vty-unix-0.2.0.0-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-unix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-unix
version:              0.2.0.0
visibility:           public
id:                   vty-unix-0.2.0.0-HiALF6Zhguw8s649QOJqPS
key:                  vty-unix-0.2.0.0-HiALF6Zhguw8s649QOJqPS
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Unix backend for Vty
description:          This package provides Unix terminal support for Vty.
category:             User Interfaces
abi:                  1403bd0afca1c50b83c6e256dcc95e02
exposed:              True
exposed-modules:
    Data.Terminfo.Eval Data.Terminfo.Parse Graphics.Vty.Platform.Unix
    Graphics.Vty.Platform.Unix.Input
    Graphics.Vty.Platform.Unix.Input.Classify
    Graphics.Vty.Platform.Unix.Input.Classify.Parse
    Graphics.Vty.Platform.Unix.Input.Classify.Types
    Graphics.Vty.Platform.Unix.Input.Focus
    Graphics.Vty.Platform.Unix.Input.Loop
    Graphics.Vty.Platform.Unix.Input.Mouse
    Graphics.Vty.Platform.Unix.Input.Paste
    Graphics.Vty.Platform.Unix.Input.Terminfo
    Graphics.Vty.Platform.Unix.Input.Terminfo.ANSIVT
    Graphics.Vty.Platform.Unix.Output
    Graphics.Vty.Platform.Unix.Output.Color
    Graphics.Vty.Platform.Unix.Output.TerminfoBased
    Graphics.Vty.Platform.Unix.Output.XTermColor
    Graphics.Vty.Platform.Unix.Settings

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vty-unix-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vty-unix-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vty-unix-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-unix
hs-libraries:         HSvty-unix-0.2.0.0-HiALF6Zhguw8s649QOJqPS
includes:             cbits/gwinsz.h
depends:
    base-4.17.2.1 blaze-builder-0.4.4-J87LvVgADYa5gww986bADm
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-mtl-0.2.1.0-LWyutRK1cqlCk2SYzoFhAy
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669 mtl-2.2.2
    parsec-3.1.16.1 stm-2.5.1.0 terminfo-0.4.1.5 transformers-0.5.6.2
    unix-2.7.3 utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-52P7Ozt5w3I6hi4WvheJB9
    vty-6.2-CDHlYy103TUGR9Lrhlf8g8

haddock-interfaces:   /usr/share/doc/haskell-vty-unix/html/vty-unix.haddock
haddock-html:         /usr/share/doc/haskell-vty-unix/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-unix-0.2.0.0-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-unix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-unix
version:              0.2.0.0
visibility:           public
id:                   vty-unix-0.2.0.0-LaAZz8NvW4qKNDeMM5ITff
key:                  vty-unix-0.2.0.0-LaAZz8NvW4qKNDeMM5ITff
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Unix backend for Vty
description:          This package provides Unix terminal support for Vty.
category:             User Interfaces
abi:                  753a3e2a97459146b4486b101ace4fb4
exposed:              True
exposed-modules:
    Data.Terminfo.Eval Data.Terminfo.Parse Graphics.Vty.Platform.Unix
    Graphics.Vty.Platform.Unix.Input
    Graphics.Vty.Platform.Unix.Input.Classify
    Graphics.Vty.Platform.Unix.Input.Classify.Parse
    Graphics.Vty.Platform.Unix.Input.Classify.Types
    Graphics.Vty.Platform.Unix.Input.Focus
    Graphics.Vty.Platform.Unix.Input.Loop
    Graphics.Vty.Platform.Unix.Input.Mouse
    Graphics.Vty.Platform.Unix.Input.Paste
    Graphics.Vty.Platform.Unix.Input.Terminfo
    Graphics.Vty.Platform.Unix.Input.Terminfo.ANSIVT
    Graphics.Vty.Platform.Unix.Output
    Graphics.Vty.Platform.Unix.Output.Color
    Graphics.Vty.Platform.Unix.Output.TerminfoBased
    Graphics.Vty.Platform.Unix.Output.XTermColor
    Graphics.Vty.Platform.Unix.Settings

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vty-unix-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vty-unix-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vty-unix-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-unix
hs-libraries:         HSvty-unix-0.2.0.0-LaAZz8NvW4qKNDeMM5ITff
includes:             cbits/gwinsz.h
depends:
    base-4.17.2.1 blaze-builder-0.4.4-EYzzAuOKf5mlUrLaPwbAW
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-mtl-0.2.1.0-LWyutRK1cqlCk2SYzoFhAy
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669 mtl-2.2.2
    parsec-3.1.16.1 stm-2.5.1.0 terminfo-0.4.1.5 transformers-0.5.6.2
    unix-2.7.3 utf8-string-1.0.2-FAQSGuIUGqDKZx6mH04y15
    vector-0.13.2.0-K0fBmK5qd7y3388236ZS0A
    vty-6.2-7q7ChOhYPGRAEcCH9L5SOt

haddock-interfaces:   /usr/share/doc/haskell-vty-unix/html/vty-unix.haddock
haddock-html:         /usr/share/doc/haskell-vty-unix/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
